==> jc-1.4.0.tar.gz: java/sql/Date.h <==
// public class java.sql.Date

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1614ce095056fc1d java_sql_Date
// @dep_class 332e5a99f29f9093 java_util_Date

// header file dependencies
// @dep_header java_util_Date

#include "java/util/Date.h"

#ifndef _JC_java_sql_Date_H_
#define _JC_java_sql_Date_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_sql_Date$object;
struct _jc_java_text_SimpleDateFormat$object;

// Typedefs
typedef struct _jc_java_sql_Date$sub_refs	_jc_java_sql_Date$sub_refs;
typedef struct _jc_java_sql_Date$sub_nonrefs	_jc_java_sql_Date$sub_nonrefs;
typedef struct _jc_java_sql_Date$refs	_jc_java_sql_Date$refs;
typedef struct _jc_java_sql_Date$nonrefs	_jc_java_sql_Date$nonrefs;
typedef struct _jc_java_sql_Date$object	_jc_java_sql_Date$object;

typedef struct _jc_java_sql_Date$fields_struct	_jc_java_sql_Date$fields_struct;
typedef const struct _jc_java_sql_Date$vmethods	_jc_java_sql_Date$vmethods;
typedef const struct _jc_java_sql_Date$vtable	_jc_java_sql_Date$vtable;
typedef const struct _jc_java_sql_Date$vtype	_jc_java_sql_Date$vtype;

// Class fields structure
struct _jc_java_sql_Date$fields_struct {
	struct _jc_java_text_SimpleDateFormat$object	*sdf;
	jlong	serialVersionUID;
};
extern _jc_java_sql_Date$fields_struct _jc_java_sql_Date$class_fields;

// Constructors
extern void _jc_java_sql_Date$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_java_sql_Date$object *, jint, jint, jint);
extern void _jc_java_sql_Date$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_java_sql_Date$object *, jlong);

// Virtual methods
extern jint _jc_java_sql_Date$method$getHours$d751046ac8d7cedf(_jc_env *, struct _jc_java_sql_Date$object *);
extern jint _jc_java_sql_Date$method$getMinutes$85b079c9ad1c9bde(_jc_env *, struct _jc_java_sql_Date$object *);
extern jint _jc_java_sql_Date$method$getSeconds$e11b3ceafb507165(_jc_env *, struct _jc_java_sql_Date$object *);
extern void _jc_java_sql_Date$method$setHours$546e779f16208fb3(_jc_env *, struct _jc_java_sql_Date$object *, jint);
extern void _jc_java_sql_Date$method$setMinutes$8f69b7baadab226c(_jc_env *, struct _jc_java_sql_Date$object *, jint);
extern void _jc_java_sql_Date$method$setSeconds$c6502d8c30371f1e(_jc_env *, struct _jc_java_sql_Date$object *, jint);
extern struct _jc_java_lang_String$object *_jc_java_sql_Date$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_sql_Date$object *);

// Virtual method descriptors
extern _jc_method _jc_java_sql_Date$method_info$getHours$d751046ac8d7cedf;
extern _jc_method _jc_java_sql_Date$method_info$getMinutes$85b079c9ad1c9bde;
extern _jc_method _jc_java_sql_Date$method_info$getSeconds$e11b3ceafb507165;
extern _jc_method _jc_java_sql_Date$method_info$setHours$546e779f16208fb3;
extern _jc_method _jc_java_sql_Date$method_info$setMinutes$8f69b7baadab226c;
extern _jc_method _jc_java_sql_Date$method_info$setSeconds$c6502d8c30371f1e;
extern _jc_method _jc_java_sql_Date$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_sql_Date$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_sql_Date$object *_jc_java_sql_Date$method$valueOf$ec92074e007f06eb(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_sql_Date$vmethods {
	jint	(*getHours$d751046ac8d7cedf)(_jc_env *, struct _jc_java_sql_Date$object *);
	jint	(*getMinutes$85b079c9ad1c9bde)(_jc_env *, struct _jc_java_sql_Date$object *);
	jint	(*getSeconds$e11b3ceafb507165)(_jc_env *, struct _jc_java_sql_Date$object *);
	void	(*setHours$546e779f16208fb3)(_jc_env *, struct _jc_java_sql_Date$object *, jint);
	void	(*setMinutes$8f69b7baadab226c)(_jc_env *, struct _jc_java_sql_Date$object *, jint);
	void	(*setSeconds$c6502d8c30371f1e)(_jc_env *, struct _jc_java_sql_Date$object *, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_sql_Date$object *);
};

// Vtable
struct _jc_java_sql_Date$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Date$vmethods	java_util_Date;
	_jc_java_sql_Date$vmethods	java_sql_Date;
};

// Vtype
struct _jc_java_sql_Date$vtype {
	_jc_type			type;
	_jc_java_sql_Date$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_Date$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_Date$refs {
    _jc_java_sql_Date$sub_refs	java_sql_Date;
    _jc_java_util_Date$sub_refs	java_util_Date;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_Date$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_Date$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Date$sub_nonrefs	java_util_Date;
    _jc_java_sql_Date$sub_nonrefs	java_sql_Date;
};

// Object instance structure
struct _jc_java_sql_Date$object {
	_jc_java_sql_Date$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_Date$vtype	*vtype;
	_jc_java_sql_Date$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_Date$vtype _jc_java_sql_Date$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_Date, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_Date$class_object;

#endif	/* _JC_java_sql_Date_H_ */

==> jc-1.4.5.tar.gz: java/sql/Date.h <==
// public class java.sql.Date

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1614ce095056fc1d java_sql_Date
// @dep_class 332e5a99f29f9093 java_util_Date

// header file dependencies
// @dep_header java_util_Date

#include "java/util/Date.h"

#ifndef _JC_java_sql_Date_H_
#define _JC_java_sql_Date_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_sql_Date$object;
struct _jc_java_text_SimpleDateFormat$object;

// Typedefs
typedef struct _jc_java_sql_Date$sub_refs	_jc_java_sql_Date$sub_refs;
typedef struct _jc_java_sql_Date$sub_nonrefs	_jc_java_sql_Date$sub_nonrefs;
typedef struct _jc_java_sql_Date$refs	_jc_java_sql_Date$refs;
typedef struct _jc_java_sql_Date$nonrefs	_jc_java_sql_Date$nonrefs;
typedef struct _jc_java_sql_Date$object	_jc_java_sql_Date$object;

typedef struct _jc_java_sql_Date$fields_struct	_jc_java_sql_Date$fields_struct;
typedef const struct _jc_java_sql_Date$vmethods	_jc_java_sql_Date$vmethods;
typedef const struct _jc_java_sql_Date$vtable	_jc_java_sql_Date$vtable;
typedef const struct _jc_java_sql_Date$vtype	_jc_java_sql_Date$vtype;

// Class fields structure
struct _jc_java_sql_Date$fields_struct {
	struct _jc_java_text_SimpleDateFormat$object	*sdf;
	jlong	serialVersionUID;
};
extern _jc_java_sql_Date$fields_struct _jc_java_sql_Date$class_fields;

// Constructors
extern void _jc_java_sql_Date$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_java_sql_Date$object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_sql_Date$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_java_sql_Date$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_sql_Date$method$getHours$d751046ac8d7cedf(_jc_env *, struct _jc_java_sql_Date$object *) _JC_JCNI_ATTR;
extern jint _jc_java_sql_Date$method$getMinutes$85b079c9ad1c9bde(_jc_env *, struct _jc_java_sql_Date$object *) _JC_JCNI_ATTR;
extern jint _jc_java_sql_Date$method$getSeconds$e11b3ceafb507165(_jc_env *, struct _jc_java_sql_Date$object *) _JC_JCNI_ATTR;
extern void _jc_java_sql_Date$method$setHours$546e779f16208fb3(_jc_env *, struct _jc_java_sql_Date$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_sql_Date$method$setMinutes$8f69b7baadab226c(_jc_env *, struct _jc_java_sql_Date$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_sql_Date$method$setSeconds$c6502d8c30371f1e(_jc_env *, struct _jc_java_sql_Date$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_sql_Date$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_sql_Date$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_sql_Date$method_info$getHours$d751046ac8d7cedf;
extern _jc_method _jc_java_sql_Date$method_info$getMinutes$85b079c9ad1c9bde;
extern _jc_method _jc_java_sql_Date$method_info$getSeconds$e11b3ceafb507165;
extern _jc_method _jc_java_sql_Date$method_info$setHours$546e779f16208fb3;
extern _jc_method _jc_java_sql_Date$method_info$setMinutes$8f69b7baadab226c;
extern _jc_method _jc_java_sql_Date$method_info$setSeconds$c6502d8c30371f1e;
extern _jc_method _jc_java_sql_Date$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_sql_Date$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_sql_Date$object *_jc_java_sql_Date$method$valueOf$ec92074e007f06eb(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_sql_Date$vmethods {
	jint	(*getHours$d751046ac8d7cedf)(_jc_env *, struct _jc_java_sql_Date$object *) _JC_JCNI_ATTR;
	jint	(*getMinutes$85b079c9ad1c9bde)(_jc_env *, struct _jc_java_sql_Date$object *) _JC_JCNI_ATTR;
	jint	(*getSeconds$e11b3ceafb507165)(_jc_env *, struct _jc_java_sql_Date$object *) _JC_JCNI_ATTR;
	void	(*setHours$546e779f16208fb3)(_jc_env *, struct _jc_java_sql_Date$object *, jint) _JC_JCNI_ATTR;
	void	(*setMinutes$8f69b7baadab226c)(_jc_env *, struct _jc_java_sql_Date$object *, jint) _JC_JCNI_ATTR;
	void	(*setSeconds$c6502d8c30371f1e)(_jc_env *, struct _jc_java_sql_Date$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_sql_Date$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_sql_Date$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Date$vmethods	java_util_Date;
	_jc_java_sql_Date$vmethods	java_sql_Date;
};

// Vtype
struct _jc_java_sql_Date$vtype {
	_jc_type			type;
	_jc_java_sql_Date$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_Date$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_Date$refs {
    _jc_java_sql_Date$sub_refs	java_sql_Date;
    _jc_java_util_Date$sub_refs	java_util_Date;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_Date$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_sql_Date$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Date$sub_nonrefs	java_util_Date;
    _jc_java_sql_Date$sub_nonrefs	java_sql_Date;
};

// Object instance structure
struct _jc_java_sql_Date$object {
	_jc_java_sql_Date$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_Date$vtype	*vtype;
	_jc_java_sql_Date$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_Date$vtype _jc_java_sql_Date$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_Date, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_Date$class_object;

#endif	/* _JC_java_sql_Date_H_ */
